=====================================
Installation and Notes for Developers
=====================================


.. contents:: Table of Contents
	      :depth: 3

If the contents do not show below, read them in :doc:`../../../README.rst`
      
.. include:: ../../../README.rst
   :start-after: Install/Uninstall


   

